const locale = {
    "Allow scroll wheel zoom?": "Autoriser le zoom avec la molette ?",
    "Automatic": "Automatique",
    "Ball": "Épingle",
    "Cancel": "Annuler",
    "Caption": "Légende",
    "Choose the data format": "Choisir le format des données",
    "Choose the layer of the feature": "Choisir le calque de l'élément",
    "Circle": "Cercle",
    "Clustered": "Avec cluster",
    "Data browser": "Visualiseur de données",
    "Default": "Par défaut",
    "Default zoom level": "Niveau de zoom par défaut",
    "Default: name": "Par défaut : name",
    "Display label": "Afficher une étiquette",
    "Display the control to open OpenStreetMap editor": "Afficher le bouton pour ouvrir l'éditeur d'OpenStreetMap",
    "Display the data layers control": "Afficher le bouton d'accès rapide aux calques de données",
    "Display the embed control": "Afficher le bouton de partage",
    "Display the fullscreen control": "Afficher le bouton de plein écran",
    "Display the locate control": "Afficher le bouton de localisation",
    "Display the measure control": "Afficher le bouton de mesures",
    "Display the search control": "Afficher le bouton de recherche",
    "Display the tile layers control": "Afficher le bouton permettant de changer le fond de carte",
    "Display the zoom control": "Afficher les boutons de zoom",
    "Do you want to display a caption bar?": "Voulez-vous afficher une barre de légende",
    "Do you want to display a minimap?": "Voulez-vous afficher une mini carte de situation ?",
    "Do you want to display a panel on load?": "Voulez-vous afficher un panneau latéral au chargement ?",
    "Do you want to display popup footer?": "Voulez-vous afficher les boutons de navigation en bas des popups ?",
    "Do you want to display the scale control?": "Voulez-vous afficher l'échelle de la carte ?",
    "Do you want to display the «more» control?": "Voulez-vous afficher le bouton « Plus » ?",
    "Drop": "Goutte",
    "GeoRSS (only link)": "GeoRSS (lien seul)",
    "GeoRSS (title + image)": "GeoRSS (titre + image)",
    "Heatmap": "Heatmap",
    "Icon shape": "Forme de l'icône",
    "Icon symbol": "Image de l'icône",
    "Inherit": "Hériter",
    "Label direction": "Direction de l'étiquette",
    "Label key": "Clé pour le libellé",
    "Labels are clickable": "Étiquette cliquable",
    "None": "Aucun",
    "On the bottom": "Bas",
    "On the left": "Gauche",
    "On the right": "Droite",
    "On the top": "Haut",
    "Popup content template": "Gabarit manuel de popup",
    "Side panel": "Panneau latéral",
    "Simplify": "Simplifier",
    "Table": "Tableau",
    "always": "toujours",
    "clear": "effacer",
    "collapsed": "fermé",
    "color": "Couleur",
    "dash array": "traitillé",
    "define": "définir",
    "description": "description",
    "expanded": "ouvert",
    "fill": "remplissage",
    "fill color": "couleur de remplissage",
    "fill opacity": "opacité du remplissage",
    "hidden": "caché",
    "iframe": "iframe",
    "inherit": "hériter",
    "name": "nom",
    "never": "jamais",
    "new window": "nouvelle fenêtre",
    "no": "non",
    "on hover": "Au survol",
    "opacity": "opacité",
    "parent window": "fenêtre parente",
    "stroke": "trait",
    "weight": "épaisseur",
    "yes": "oui",
    "{delay} seconds": "{delay} secondes",
    "# one hash for main heading": "# un dièse pour titre 1",
    "## two hashes for second heading": "## deux dièses pour titre 2",
    "### three hashes for third heading": "### trois dièses pour titre 3",
    "**double star for bold**": "**double astérisque pour gras**",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Liste de nombres séparés par une virgule, définissant les tirets et espaces. Ex.: \"5, 10, 15\".",
    "About": "À propos",
    "Activate slideshow mode": "Activer le mode diaporama",
    "Add a layer": "Ajouter un calque",
    "Add a line to the current multi": "Ajouter une ligne au groupe courant",
    "Add a new property": "Ajouter une propriété",
    "Add a polygon to the current multi": "Ajouter un polygon au groupe courant",
    "Advanced actions": "Actions avancées",
    "Advanced properties": "Propriétés avancées",
    "All properties are imported.": "Toutes les propriétés sont importées.",
    "Allow interactions": "Autoriser les interactions",
    "Are you sure you want to cancel your changes?": "Êtes-vous sûr de vouloir annuler vos modifications ?",
    "Are you sure you want to clone this map and all its datalayers?": "Êtes-vous sûr de vouloir cloner cette carte et ses calques de données?",
    "Are you sure you want to delete the feature?": "Êtes-vous sûr de vouloir supprimer cet élément?",
    "Are you sure you want to delete this layer?": "Voulez-vous vraiment supprimer ce calque ?",
    "Are you sure you want to delete this map?": "Êtes-vous sûr de vouloir supprimer cette carte?",
    "Are you sure you want to delete this property on all the features?": "Supprimer la propriété sur tous les éléments ?",
    "Are you sure you want to restore this version?": "Êtes-vous sûr de vouloir restaurer cette version ?",
    "Attach the map to my account": "Lier cette carte à mon compte",
    "Auto": "Auto",
    "Autostart when map is loaded": "Lancer au chargement de la carte",
    "Browse data": "Visualiser les données",
    "Cancel edits": "Annuler les modifications",
    "Center map on your location": "Centrer la carte sur votre position",
    "Change map background": "Changer le fond de carte",
    "Change tilelayers": "Changer le fond de carte",
    "Choose a preset": "Choisir dans les présélections",
    "Choose the format of the data to import": "Choisir le format des données pour l'import",
    "Choose the layer to import in": "Choisir le calque de données pour l'import",
    "Click last point to finish shape": "Cliquer sur le dernier point pour finir le tracé",
    "Click to add a marker": "Cliquer pour ajouter le marqueur",
    "Click to continue drawing": "Cliquer pour continuer le tracé",
    "Click to edit": "Cliquer pour modifier",
    "Click to start drawing a line": "Cliquer pour commencer une ligne",
    "Click to start drawing a polygon": "Cliquer pour commencer un polygone",
    "Clone": "Cloner",
    "Clone of {name}": "Clone de {name}",
    "Clone this feature": "Dupliquer",
    "Clone this map": "Cloner cette carte",
    "Close": "Fermer",
    "Clustering radius": "Rayon du cluster",
    "Comma separated list of properties to use when filtering features": "Propriétés à utiliser pour filtrer les éléments (séparées par des virgules)",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Virgule, tabulation ou point-virgule pour séparer des valeurs. SRS WGS84 est implicite. Seuls les points géométriques sont importés. L'importation se référera au titre dans les entêtes de colonnes de «lat» et «lon» au début de l'en-tête, et est insensible à la casse. Toutes les autres colonnes sont importées en tant que propriétés.",
    "Continue line": "Continuer la ligne",
    "Continue line (Ctrl+Click)": "Continue la ligne (Ctrl+Clic)",
    "Coordinates": "Coordonnées",
    "Credits": "Crédits",
    "Current view instead of default map view?": "Vue courante plutôt que la vue par défaut ?",
    "Custom background": "Fond de carte personnalisé",
    "Data is browsable": "Données naviguables",
    "Default interaction options": "Options d'interaction par défaut",
    "Default properties": "Propriétés par défaut",
    "Default shape properties": "Propriétés de forme par défaut",
    "Define link to open in a new window on polygon click.": "Définit un lien à ouvrir dans une nouvelle fenêtre au clic sur le polygone.",
    "Delay between two transitions when in play mode": "Délai entre les transitions en mode lecture",
    "Delete": "Supprimer",
    "Delete all layers": "Supprimer tous les calques",
    "Delete layer": "Supprimer le calque",
    "Delete this feature": "Supprimer cet élément",
    "Delete this property on all the features": "Supprimer cette propriété",
    "Delete this shape": "Supprimer ce tracé",
    "Delete this vertex (Alt+Click)": "Supprimer ce point (Alt+Clic)",
    "Directions from here": "Itinéraire à partir de ce lieu",
    "Display measure": "Afficher les dimensions",
    "Display on load": "Afficher au chargement",
    "Download": "Télécharger",
    "Drag to reorder": "Glisser pour réordonner",
    "Draw a marker": "Ajouter un marqueur",
    "Draw a polygon": "Dessiner un polygone",
    "Draw a polyline": "Dessiner une ligne",
    "Dynamic": "Dynamique",
    "Dynamic properties": "Propriétés dynamiques",
    "Edit": "Éditer",
    "Edit feature's layer": "Éditer le calque de l'élément",
    "Edit map properties": "Éditer les propriétés de la carte",
    "Edit properties in a table": "Éditer dans un tableau",
    "Edit this feature": "Éditer cet élément",
    "Embed the map": "Intégrer la carte dans une iframe",
    "Empty": "Vider",
    "Error in the tilelayer URL": "Erreur dans l'URL du fond de carte",
    "Exit Fullscreen": "Quitter le plein écran",
    "Extract shape to separate feature": "Extraire la forme",
    "Fetch data each time map view changes.": "Récupère les données à chaque fois que la vue de la carte change.",
    "Filter keys": "Clés de filtre",
    "Format": "Format",
    "From zoom": "À partir du zoom",
    "Go to «{feature}»": "Naviguer jusqu'à «{feature}»",
    "Heatmap intensity property": "Propriété pour l'intensité de la heatmap",
    "Heatmap radius": "Rayon de heatmap",
    "Help": "Aide",
    "Hide controls": "Masquer les outils",
    "Home": "Accueil",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Valeur de simplification des lignes pour chaque niveau de zoom (grand nombre = meilleure performance, petit nombre = plus précis)",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe avec hauteur (en pixels): {{{http://iframe.url.com|hauteur}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe avec hauteur et largeur (en px) : {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe : {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Image avec largeur (en pixels) : {{http://image.url.com|largeur}}",
    "Image: {{http://image.url.com}}": "Image : {{http://image.url.com}}",
    "Import": "Importer",
    "Import data": "Importer des données",
    "Import in a new layer": "Importer dans un nouveau calque",
    "Imports all umap data, including layers and settings.": "Importer toutes les données de la carte, y compris les calques et les propriétés",
    "Include full screen link?": "Inclure le lien \"plein écran\" ?",
    "Interaction options": "Options d'interaction",
    "Invalid umap data": "Données uMap invalides",
    "Invalid umap data in {filename}": "Les données du fichier {filename} ne sont pas valides comme format uMap",
    "Keep current visible layers": "Garder les calques visibles actuellement",
    "Latitude": "Latitude",
    "Layer": "Calque",
    "Layer properties": "Propriétés du calque",
    "Licence": "Licence",
    "Limit bounds": "Limites géographiques",
    "Link to…": "Lien vers…",
    "Link with text: [[http://example.com|text of the link]]": "Lien avec texte : [[http://exemple.fr|texte du lien]]",
    "Long credits": "Crédit",
    "Longitude": "Longitude",
    "Make main shape": "Tracé principal",
    "Manage layers": "Gérer les calques",
    "Map background credits": "Crédits pour le fond de carte",
    "Map has been attached to your account": "La  carte est maintenant liée à votre compte",
    "Map has been saved!": "La carte a été sauvegardée !",
    "Map user content has been published under licence": "Les contenus sur la carte ont été publiés avec la licence",
    "Map's editors": "Éditeurs de la carte",
    "Map's owner": "Propriétaire de la carte",
    "Merge lines": "Fusionner les lignes",
    "More controls": "Plus d'outils",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Doit être une valeur CSS valide (ex. : DarkBlue ou #123456)",
    "No licence has been set": "Aucune licence définie",
    "No results": "Aucun résultat",
    "Open link in…": "Ouvrir le lien dans…",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Ouvrir cette carte dans un éditeur OpenStreetMap pour améliorer les données",
    "Optional intensity property for heatmap": "Propriété optionnelle à utiliser pour calculer l'intensité de la heatmap",
    "Optional. Same as color if not set.": "Optionnel. La couleur principale sera utilisée si laissé vide.",
    "Override clustering radius (default 80)": "Valeur de rayon personnalisée pour le cluster (par défaut : 80)",
    "Override heatmap radius (default 25)": "Valeur de rayon personnalisée pour la heatmap (par défaut : 25)",
    "Please be sure the licence is compliant with your use.": "Pensez à vérifier que la licence de ces données vous autorise à les utiliser.",
    "Please choose a format": "Merci de choisir un format",
    "Please enter the name of the property": "Merci d'entrer le nom de la propriété",
    "Please enter the new name of this property": "Veuillez entrer le nouveau nom de la propriété",
    "Properties imported:": "Propriétés importées :",
    "Provide an URL here": "Renseigner une URL",
    "Proxy request": "Avec proxy",
    "Remote data": "Données distantes",
    "Remove shape from the multi": "Extraire le tracé du groupe",
    "Rename this property on all the features": "Renommer la propriété",
    "Replace layer content": "Remplacer le contenu du calque",
    "Restore this version": "Restaurer cette version",
    "Save": "Enregistrer",
    "Save anyway": "Continuer",
    "Save current edits": "Enregistrer les changements courants",
    "Save this center and zoom": "Enregistrer le zoom et le centre actuels",
    "Save this location as new feature": "Enregistrer ce lieu comme élément de la carte",
    "Search location": "Chercher un lieu",
    "See all": "Tout voir",
    "See data layers": "Voir les calques",
    "See full screen": "Voir en plein écran",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Désactiver pour masquer ce calque du diaporama, du navigateur de données…",
    "Shape properties": "Propriétés de la forme",
    "Short credits": "Crédit court",
    "Show/hide layer": "Montrer/masquer un calque",
    "Simple link: [[http://example.com]]": "Lien simple : [[https://exemple.fr]]",
    "Slideshow": "Diaporama",
    "Sort key": "Clé de tri",
    "Split line": "Scinder la ligne",
    "Start a hole here": "Ajouter un tracé intérieur",
    "Start slideshow": "Commencer",
    "Stop editing": "Quitter le mode édition",
    "Stop slideshow": "Arrêter",
    "Supported scheme": "Schéma supporté",
    "Supported variables that will be dynamically replaced": "Variables qui seront automatiquement remplacées",
    "TMS format": "format de type TMS",
    "Text color for the cluster label": "Couleur du texte du cluster",
    "Text formatting": "Mise en forme du texte",
    "To use if remote server doesn't allow cross domain (slower)": "Cocher si le serveur distant n'autorise pas le cross domain (plus lent)",
    "To zoom": "Jusqu'au zoom",
    "Transfer shape to edited feature": "Adjoindre le tracé au groupe courant",
    "Transform to lines": "Transformer en lignes",
    "Transform to polygon": "Transformer en polygone",
    "Type of layer": "Type de calque",
    "Unable to detect format of file {filename}": "Impossible de détecter le format du fichier {filename}",
    "Untitled layer": "Calque sans nom",
    "Untitled map": "Carte sans nom",
    "Update permissions": "Mettre à jour les permissions",
    "Update permissions and editors": "Changer les permissions et les éditeurs",
    "Url": "URL",
    "Use current bounds": "Utiliser la vue courante",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Utilisez des variables avec les noms de propriétés de vos éléments entre accolades, ex.  &#123;name&#125;, elles seront remplacées dynamiquement par les valeurs correspondantes.",
    "User content credits": "Crédit pour le contenu utilisateur",
    "User interface options": "Options d'interface",
    "Versions": "Versions",
    "View Fullscreen": "Voir en plein écran",
    "Where do we go from here?": "C'est par où pour aller plus loin?",
    "Whether to display or not polygons paths.": "Afficher les contours des polygones.",
    "Whether to fill polygons with color.": "Remplir les polygones avec de la couleur.",
    "Who can edit": "Qui peut modifier",
    "Who can view": "Qui peut voir",
    "Will be displayed in the bottom right corner of the map": "S'affiche dans le coin en bas à droite de la carte",
    "Will be visible in the caption of the map": "Sera visible dans la légende de la carte",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Aïe ! Quelqu'un d'autre semble avoir modifié la carte. Vous pouvez continuer l'enregistrement, mais ses données seront perdues.",
    "Zoom in": "Zoomer",
    "Zoom level for automatic zooms": "Niveau de zoom automatique",
    "Zoom out": "Dézoomer",
    "Zoom to layer extent": "Zoomer jusqu'à voir les données du calque",
    "Zoom to the next": "Suivant",
    "Zoom to the previous": "Précédent",
    "Zoom to this feature": "Zoomer sur cet élément",
    "Zoom to this place": "Zoomer vers ce lieu",
    "attribution": "attribution",
    "by": "par",
    "display name": "nom",
    "height": "hauteur",
    "licence": "licence",
    "max East": "limite est",
    "max North": "limite nord",
    "max South": "limite sud",
    "max West": "limite ouest",
    "max zoom": "zoom max",
    "min zoom": "zoom min",
    "next": "suivant",
    "previous": "précédent",
    "width": "largeur",
    "{count} errors during import: {message}": "{count} erreurs pendant l'import: {message}",
    "Measure distances": "Mesurer les distances",
    "NM": "NM",
    "kilometers": "kilomètres",
    "km": "km",
    "mi": "mi",
    "miles": "miles",
    "nautical miles": "miles nautiques",
    "1 day": "1 jour",
    "1 hour": "1 heure",
    "5 min": "5 min",
    "Cache proxied request": "Cacher la requête avec proxy",
    "No cache": "Pas de cache",
    "Popup": "Popup",
    "Popup (large)": "Popup (grande)",
    "Popup content style": "Gabarit prédéfini de popup",
    "Popup shape": "Forme de popup",
    "Skipping unknown geometry.type: {type}": "Type de géométrie inconnu ignoré: {type}",
    "Optional.": "Facultatif",
    "Paste your data here": "Collez vos données ici",
    "Please save the map first": "Vous devez d'abord enregistrer la carte",
    "Feature identifier key": "Clé unique d'un élément",
    "Open current feature on load": "Ouvrir l'élément courant au chargement",
    "Permalink": "Permalien",
    "The name of the property to use as feature unique identifier.": "Nom de la propriété utilisée pour identifier un élément de façon unique",
    "Do you want to display caption menus?": "Afficher les menus dans la légende ?",
    "Example: key1,key2,key3": "Exemple: clé1,clé2,clé3",
    "Invalid latitude or longitude": "Latitude ou longitude invalide",
    "Invalide property name: {name}": "Nom de propriété invalide: {name}",
    "Permanent credits": "Crédits permanents",
    "Permanent credits background": "Afficher un fond pour le crédit permanent",
    "Select data": "Sélectionner les données",
    "Will be permanently visible in the bottom left corner of the map": "Afficher en permanence au coin en bas à gauche de la carte",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{distance}&#8239;NM": "{distance} MN",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;yd": "{distance} yd",
    " (area: {measure})": "(surface: {measure})",
    " (length: {measure})": "(longueur: {measure})",
    "Animated transitions": "Transitions animées",
    "Background overlay url": "URL de fond transparent",
    "Custom overlay": "Fond transparent",
    "Display the star map button": "Afficher le bouton pour mettre une carte en favori",
    "Error in the overlay URL": "URL du fond de carte invalide",
    "Map has been starred": "La carte a été ajoutée aux favoris",
    "Map has been unstarred": "La carte a été supprimée des favoris",
    "Opacity": "Transparence",
    "Star this map": "Mettre la carte en favori",
    "Symbol can be either a unicode character or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Utilisez soit un caractère unique soit une URL. Vous pouvez utiliser des propriétés des marqueurs comme variables : par exemple avec \"http://myserver.org/images/{name}.png\", la variable {name} sera remplacée par la valeur de \"name\" de chacun des marqueurs.",
    "Direct link": "Lien",
    "The zoom and center have been modified.": "Le niveau de zoom et le centre ont été modifiés.",
    "Congratulations, your map has been created!": "Félicitations, votre carte a bien été créée !",
    "Copy link": "Copier le lien",
    "Email": "Courriel",
    "Secret edit link copied to clipboard!": "Lien d'édition secret copié dans le presse-papier!",
    "Send me the link": "Envoyer le lien",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Votre carte a été créée! Comme vous n'êtes pas identifié, voici le lien secret pour éditer la carte à l'avenir, conservez-le précieusement:",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Liste de propriétés séparées par une virgule pour trier les éléments. Pour trier en descendant, ajouter un signe moins (-) devant. Ex.: maclé,-autreclé.",
    "Toggle edit mode (⇧+Click)": "Alterner le mode édition (⇧+clic)",
    "icon opacity": "Opacité de l'icône",
    "*single star for italic*": "*simple astérisque pour italique*",
    "--- for a horizontal rule": "--- pour un séparateur horizontal",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"{name} in {place}\")": "Nom de la propriété utilisée pour le libellé (ex.: \"nom\"). Il est possible d'utiliser des propriétés entre accolades pour en utiliser plusieurs ou ajouter du texte (ex.: \"{nom} à {lieu}\")",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key)": "Liste de propriétés séparées par des virgules pour calculer les facettes (ex.: macle,monautrecle). Pour définir un libellé, on peut l'ajouter après un | (ex.: macle|Ma Clé,monautrecle|Mon Autre Clé)",
    "Default view": "Vue par défaut",
    "Facet keys": "Clés pour les facettes",
    "Facet search": "Recherche par facette",
    "Feature properties": "Propriétés de l'élément",
    "Latest feature": "Dernier élément",
    "No results for these facets": "Aucun résultat pour ces facettes",
    "Saved center and zoom": "Centre et zoom enregistrés",
    "User location": "Localisation de l'utilisateur",
    "Visibility: {status}": "Visibilité: {status}",
    "Fit all data": "Zoom sur les données",
    "Verify remote URL": "Vérifier l'URL",
    "Add": "Ajouter",
    "Change": "Modifier",
    "Powered by uMap": "Propulsé par uMap",
    "Search": "Chercher",
    "Datalayers": "Calques",
    "Secret edit link:": "Lien d'édition secret :",
    "Who can edit \"{layer}\"": "Qui peut modifier « {layer} »",
    "Choropleth": "Choroplèthe",
    "Choropleth breakpoints": "Seuils choropleth",
    "Choropleth classes": "Classes choropleth",
    "Choropleth color palette": "Palettes de couleurs choropleth",
    "Choropleth mode": "Mode choropleth",
    "Choropleth property value": "Propriété choropleth",
    "Comma separated list of numbers, including min and max values.": "Liste de nombres séparés par des virgules, y compris les valeurs minimale et maximale.",
    "Equidistant": "Équidistant",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-moyennes",
    "Manual": "Manuel",
    "Number of desired classes (default 5)": "Nombre désiré de classes (par défaut 5)",
    "Quantiles": "Quantiles",
    "Show this layer in the caption": "Montrer ce calque dans la légende",
    "Back to preview": "Voir l'aperçu",
    "Drawing": "Modification",
    "Edit the title of the map": "Modifier le titre de la carte",
    "Go to the homepage": "Retour à la page d'accueil",
    "Switch to edit mode": "Basculer en mode édition",
    "Update who can see and edit the map": "Définir qui peut voir et modifier la carte",
    "View": "Aperçu",
    "Add image URL": "URL d'une image",
    "Emoji & Character": "Emoji & texte",
    "Generic": "Générique",
    "Symbol": "Symbole",
    "Type char or paste emoji": "Taper un caractère ou un émoji",
    "URL": "URL",
    "If false, the polygon or line will act as a part of the underlying map.": "Désactiver pour que le polygone ou la ligne ne réagisse plus aux intéractions",
    "Save map": "Enregistrer la carte",
    "Toggle edit mode": "Activer/désactiver le mode édition",
    "All data and settings of the map": "Toutes les données et les propriétés de la carte",
    "Embed and link options": "Intégration et partage",
    "Go to \"{coords}\"": "Aller à \"{coords}\"",
    "Link to view the map": "Lien vers la carte",
    "No.": "Non.",
    "Only visible layers' data": "Seules les données des calques visibles",
    "Open share & download panel": "Ouvrir le panneau de partage",
    "OpenStreetMap": "OpenStreetMap",
    "See on OpenStreetMap": "Voir sur OpenStreetMap",
    "Share and download": "Partager et télécharger",
    "Share this link to open a customized map view": "Partager ce lien pour avoir une vue personnalisée",
    "Short link": "Lien court",
    "Street": "Rue",
    "Type a place name or coordinates": "Entrer un lieu ou des coordonnées",
    "copy": "copier",
    "full backup": "sauvegarde complète",
    "settings": "paramètres",
    "Action not allowed :(": "Action non autorisée :(",
    "Bring feature to center": "Centrer la carte sur cet élément",
    "Current map view": "Lister seulement les éléments visibles",
    "Features in this layer: {count}": "Éléments dans ce calque: {count}",
    "Filter": "Filtrer",
    "Problem in the response": "Problème dans la réponse du serveur",
    "Recent": "Récents"
}
L.registerLocale("fr", locale)
L.setLocale("fr")
